@@ -470,7 +470,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
  'HAVE_RL_RESIZE_TERMINAL': 1,
- 'HAVE_RPC_RPC_H': 1,
+ 'HAVE_RPC_RPC_H': 0,
  'HAVE_RTPSPAWN': 0,
  'HAVE_SCHED_GET_PRIORITY_MAX': 1,
  'HAVE_SCHED_H': 1,
@@ -810,9 +810,9 @@ build_time_vars = {'ABIFLAGS': '',
                    '_sha1  _sha2  _sha3  _blake2  pyexpat  _elementtree  '
                    '_codecs_cn  _codecs_hk  _codecs_iso2022  _codecs_jp  '
                    '_codecs_kr  _codecs_tw  _multibytecodec  unicodedata  '
-                   '_crypt  fcntl  grp  mmap  nis  ossaudiodev  '
-                   '_posixsubprocess  resource  select  _socket  spwd  syslog  '
-                   'termios  _posixshmem  _multiprocessing  _ctypes  _curses  '
+                   '_crypt  fcntl  grp  mmap  ossaudiodev  _posixsubprocess  '
+                   'resource  select  _socket  spwd  syslog  termios  '
+                   '_posixshmem  _multiprocessing  _ctypes  _curses  '
                    '_curses_panel  _sqlite3  _ssl  _hashlib  _uuid  _tkinter  '
                    'xxsubtype  _xxtestfuzz  _testbuffer  _testinternalcapi  '
                    '_testcapi  _testclinic  _testimportmultiple  '
@@ -843,7 +843,7 @@ build_time_vars = {'ABIFLAGS': '',
                     '_lzma zlib _dbm _gdbm readline _md5 _sha1 _sha2 _sha3 '
                     '_blake2 pyexpat _elementtree _codecs_cn _codecs_hk '
                     '_codecs_iso2022 _codecs_jp _codecs_kr _codecs_tw '
-                    '_multibytecodec unicodedata _crypt fcntl grp mmap nis '
+                    '_multibytecodec unicodedata _crypt fcntl grp mmap '
                     'ossaudiodev _posixsubprocess resource select _socket spwd '
                     'syslog termios _posixshmem _multiprocessing _ctypes '
                     '_curses _curses_panel _sqlite3 _ssl _hashlib _uuid '
@@ -873,9 +873,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE_MATH_LDFLAGS': '-lm',
  'MODULE_MATH_STATE': 'yes',
  'MODULE_MMAP_STATE': 'yes',
- 'MODULE_NIS_CFLAGS': '-I/usr/include/tirpc',
- 'MODULE_NIS_LDFLAGS': '-lnsl -ltirpc',
- 'MODULE_NIS_STATE': 'yes',
+ 'MODULE_NIS_STATE': 'missing',
  'MODULE_OBJS': '\\',
  'MODULE_OSSAUDIODEV_LDFLAGS': '',
  'MODULE_OSSAUDIODEV_STATE': 'yes',
@@ -1390,7 +1388,6 @@ build_time_vars = {'ABIFLAGS': '',
                'Modules/fcntl.cpython-312-powerpc64le-linux-gnu.so '
                'Modules/grp.cpython-312-powerpc64le-linux-gnu.so '
                'Modules/mmap.cpython-312-powerpc64le-linux-gnu.so '
-               'Modules/nis.cpython-312-powerpc64le-linux-gnu.so '
                'Modules/ossaudiodev.cpython-312-powerpc64le-linux-gnu.so '
                'Modules/_posixsubprocess.cpython-312-powerpc64le-linux-gnu.so '
                'Modules/resource.cpython-312-powerpc64le-linux-gnu.so '
